@@ -18,15 +18,29 @@ class OrdbokFlaskConfig(BaseConfig, Ordbok):
         return self.root_path
 
 
+def make_config(self, instance_relative=False):
+    root_path = self.root_path
+    if instance_relative:
+        root_path = self.instance_path
+    return self.config_class(root_path, self.default_config)
+
+
+def run(self, *args, **kwargs):
+    if self.config_class is not OrdbokFlaskConfig:
+        raise Exception(
+            'Cannot override Flask.run() without using OrdbokFlaskConfig '
+            'as Flask.config_class.')
+    if kwargs.get('use_reloader') is not False and self.debug:
+        kwargs.setdefault('extra_files', [])
+        kwargs['extra_files'].extend(self.config.config_file_names)
+    return super(Flask, self).run(*args, **kwargs)
+
+
 class Flask(BaseFlask):
     """
     Extened version of `Flask` that implements the custom config class
     defined above.
     """
     config_class = OrdbokFlaskConfig
-
-    def make_config(self, instance_relative=False):
-        root_path = self.root_path
-        if instance_relative:
-            root_path = self.instance_path
-        return self.config_class(root_path, self.default_config)
+    make_config = make_config
+    run = run
